%global shortname da

Name:           devassistant
Version:        0.7.0
Release:        1%{?dist}
Summary:        Developer tool for setting up projects quickly

License:        GPLv2+
URL:            https://github.com/bkabrda/devassistant
Source0:        https://pypi.python.org/packages/source/d/%{name}/%{name}-%{version}.tar.gz
Patch0:         devassistant-0.6.0-alter-paths-for-fedora.patch
BuildArch:      noarch
 
BuildRequires:  pytest
BuildRequires:  python2-devel
BuildRequires:  python-flexmock
BuildRequires:  python-setuptools

BuildRequires:  PyYAML

# it seems that other packages using bash-completion don't depend
# on it and rather just own the directory, so we will do the same
Requires:       git
Requires:       polkit
Requires:       pygobject3
Requires:       python-PyGithub
Requires:       python-setuptools
Requires:       PyYAML

%global __requires_exclude ^\(/usr/bin/php\|/usr/bin/perl\|perl\\(\)

%description
Developer assistant is a tool for all developers using (not-only) Fedora.
It helps with creating and setting up basic projects in many languages,
setting up development environment, setting up source control and
installing dependencies.

%prep
%setup -q -n %{name}-%{version}
# Remove bundled egg-info
rm -rf %{name}.egg-info

%build
%{__python} setup.py build

%install
%{__python} setup.py install --skip-build --root %{buildroot}

# install manpages for both short and long forms of the binaries
mkdir -p %{buildroot}%{_mandir}/man1
install -p manpages/%{shortname}.1 %{buildroot}%{_mandir}/man1
install -p manpages/%{shortname}-gui.1 %{buildroot}%{_mandir}/man1
install -p manpages/%{name}.1 %{buildroot}%{_mandir}/man1
# bash completion script
mkdir -p %{buildroot}%{_sysconfdir}/bash_completion.d/
install -p %{shortname}.bash %{buildroot}%{_sysconfdir}/bash_completion.d/

## move data (assistants, snippets, templates) into %%{_datadir}
# first, do the alterations to paths in devassistant
pushd %{buildroot}%{python_sitelib}
patch -p1 < %{PATCH0}
sed -i 's|_DATADIR_DEVASSISTANT|%{_datadir}/%{name}|' devassistant/settings.py
popd
# now actually move the stuff
mv %{buildroot}%{python_sitelib}/%{name}/data %{buildroot}%{_datadir}/%{name}
# remove git subproject files
rm -rf %{buildroot}%{_datadir}/%{name}/.git*

# make sure that we have all the essential dirs, if not created previously by copying
mkdir -p %{buildroot}%{_datadir}/%{name}/{assistants/{creator/modifier/preparer},files,icons,snippets}
mkdir -p %{buildroot}%{_prefix}/local/share/%{name}/{assistants/{creator,modifier,preparer},files,icons,snippets}

%check
%{__python} setup.py test -t py.test

%files
%doc README.rst LICENSE
%{_bindir}/%{shortname}
%{_bindir}/%{shortname}-gui
%{_bindir}/%{name}
%{_datadir}/%{name}
%{_prefix}/local/share/%{name}
%{_mandir}/man1/%{shortname}.1.gz
%{_mandir}/man1/%{shortname}-gui.1.gz
%{_mandir}/man1/%{name}.1.gz
%{_sysconfdir}/bash_completion.d/
%{python_sitelib}/%{name}
%{python_sitelib}/%{name}-%{version}-py?.?.egg-info

%changelog
* Wed Oct 02 2013 Bohuslav Kabrda <bkabrda@redhat.com> - 0.7.0-1
- Update to 0.7.0.

* Wed Aug 28 2013 Bohuslav Kabrda <bkabrda@redhat.com> - 0.6.1-2
- Properly create and own the /usr/local hierarchy.

* Wed Aug 28 2013 Bohuslav Kabrda <bkabrda@redhat.com> - 0.6.1-1
- Update to 0.6.1.
- Introduce gui, add its dependencies.

* Sat Aug 03 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.5.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Fri Jul 26 2013 Bohuslav Kabrda <bkabrda@redhat.com> - 0.5.0-1
- Update to 0.5.0.
- Regenerated patch0.

* Wed Jul 17 2013 Petr Pisar <ppisar@redhat.com> - 0.4.0-3
- Perl 5.18 rebuild

* Wed Jul 03 2013 Bohuslav Kabrda <bkabrda@redhat.com> - 0.4.0-2
- Fix manpage typo, rhbz#980646.

* Mon Jul 01 2013 Bohuslav Kabrda <bkabrda@redhat.com> - 0.4.0-1
- Update to 0.4.0.

* Wed May 15 2013 Bohuslav Kabrda <bkabrda@redhat.com> - 0.3.1-1
- Update to 0.3.1.
- Remove no longer needed dependencies (jinja2, plumbum).

* Wed Mar 20 2013 Bohuslav Kabrda <bkabrda@redhat.com> - 0.2.2-1
- Update to 0.2.2 because of minor bug in 0.2.1.

* Wed Mar 20 2013 Bohuslav Kabrda <bkabrda@redhat.com> - 0.2.1-1
- Update to devassistant 0.2.1.
- Introduce bash completion script.

* Mon Mar 18 2013 Bohuslav Kabrda <bkabrda@redhat.com> - 0.2.0-1
- Update to devassistant 0.2.0.
- Move assistants and snippets to %%{datadir}/%%{name}.
- Introduce manpage.

* Tue Mar 12 2013 Bohuslav Kabrda <bkabrda@redhat.com> - 0.1.0-3
- Move templates to %%{_datadir}.

* Tue Mar 12 2013 Bohuslav Kabrda <bkabrda@redhat.com> - 0.1.0-2
- Use BR: python2-devel instead of python-devel.

* Fri Mar 08 2013 Bohuslav Kabrda <bkabrda@redhat.com> - 0.1.0-1
- Initial package.
